<?php

namespace Litepci\Engagement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Engagement\Models\Engagement;

class EngagementPolicy
{

    /**
     * Determine if the given user can view the engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Engagement $engagement)
    {
        if ($user->canDo('engagement.engagement.view') && $user->isAdmin()) {
            return true;
        }

        return $engagement->user_id == user_id() && $engagement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('engagement.engagement.create');
    }

    /**
     * Determine if the given user can update the given engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Engagement $engagement)
    {
        if ($user->canDo('engagement.engagement.edit') && $user->isAdmin()) {
            return true;
        }

        return $engagement->user_id == user_id() && $engagement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Engagement $engagement)
    {
        return $engagement->user_id == user_id() && $engagement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Engagement $engagement)
    {
        if ($user->canDo('engagement.engagement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given engagement.
     *
     * @param UserPolicy $user
     * @param Engagement $engagement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Engagement $engagement)
    {
        if ($user->canDo('engagement.engagement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
