<?php

namespace Litepci\Engagement\Providers;

use Illuminate\Support\ServiceProvider;

class EngagementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'engagement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'engagement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litepci.engagement', function ($app) {
            return $this->app->make('Litepci\Engagement\Engagement');
        });

                // Bind Engagement to repository
        $this->app->bind(
            'Litepci\Engagement\Interfaces\EngagementRepositoryInterface',
            \Litepci\Engagement\Repositories\Eloquent\EngagementRepository::class
        );

        $this->app->register(\Litepci\Engagement\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Engagement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.engagement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/engagement.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/engagement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/engagement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
